#
# spec file for package gnuplot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without  h3d_gridbox
%if 0%{suse_version} > 1310
%define qtver 5
%else
%define qtver 4
%endif
Name:           gnuplot
BuildRequires:  ImageMagick
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  emacs-nox
BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  netpbm
BuildRequires:  pango-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(caca)
BuildRequires:  pkgconfig(x11)
%if %qtver >= 5
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
%else
BuildRequires:  libqt4-devel >= 4.5
%endif 
BuildRequires:  fdupes
BuildRequires:  latex2html
BuildRequires:  lua-devel
BuildRequires:  makeinfo
BuildRequires:  plotutils-devel
BuildRequires:  texlive-dvips
BuildRequires:  texlive-epstopdf
BuildRequires:  texlive-latex
BuildRequires:  texlive-latexconfig
BuildRequires:  texlive-tex
BuildRequires:  texlive-tex4ht
BuildRequires:  texlive-texinfo
BuildRequires:  texlive-ucs
BuildRequires:  texlive-ucs
BuildRequires:  zziplib
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcerf)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(hyperref.sty)
BuildRequires:  tex(pdftex.def)
BuildRequires:  tex(subfigure.sty)
%if 0%{?suse_version} > 0 && 0%{?suse_version} <= 1310
BuildRequires:  wxWidgets-devel
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%else
BuildRequires:  wxWidgets-devel >= 3
%endif
Url:            http://www.gnuplot.info/
Version:        5.2.2
Release:        lp152.5.110
Summary:        Function Plotting Utility and more
License:        SUSE-Gnuplot and GPL-2.0+
Group:          Productivity/Graphics/Visualization/Graph
Source0:        http://downloads.sourceforge.net/project/gnuplot/gnuplot/%{version}/gnuplot-%{version}.tar.gz
Source2:        gnuplot-fr.doc.bz2
Source3:        README.whynot
# According to the gnuplot 5.0.0 release notes, the emacs .el should now be
# available at https://github.com/rudi/gnuplot-el but it doesn't exist anymore.
# Use the files from the lisp/ directory from gnuplot' CVS just before it was
# removed on 6 March 2014.
Source4:        gnuplot-el.tar.bz2
# http://mirrors.ctan.org/macros/latex209/contrib/picins/picins.sty
# That's a build requirement, not provided by Tex Live
Source5:        picins.sty
# Repair broken texi(nfo) file
Source6:        gnuplot-5.2.0-texi2info.patch
Patch0:         gnuplot-4.6.0.dif
Patch1:         gnuplot-4.4.0-x11ovf.dif
Patch2:         gnuplot-4.6.0-fonts.diff
Patch4:         gnuplot-4.6.0-demo.diff
Patch5:         gnuplot-wx3.diff
Patch6:         gnuplot-QtCore-PIC.dif
Patch7:         gnuplot-gd.patch
# PATCH-FIX-UPSTREAM upstream cimmit for boo#1117463, #1117464, and #1117465
Patch8:         gnuplot-e3cc539c.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{expand: %%global _exec_prefix %(type -p pkg-config &>/dev/null && pkg-config --variable prefix x11 || echo /usr/X11R6)}
%if "%_exec_prefix" == "/usr/X11R6"
%define _x11lib     %{_exec_prefix}/%{_lib}
%define _x11data    %{_exec_prefix}/lib/X11
%define _libx11     %{_x11data}
%define _x11inc     %{_exec_prefix}/include
%define _appdef     %{_x11data}/app-defaults
%else
%define _x11lib     %{_libdir}
%define _x11data    %{_datadir}/X11
%define _libx11     %{_exec_prefix}/lib/X11
%define _x11inc     %{_includedir}
%define _appdef     %{_x11data}/app-defaults
%endif
%define _gnplttex   tex/latex/gnuplot

%description
GNUplot is a command line driven interactive function plotting utility.
 GNUplot supports many different types of terminals, plotters, and
printers (including many color devices and pseudodevices like LaTeX)
and can easily be extended to include new devices.

%package doc
Summary:        Documentation of GNUplot
Group:          Productivity/Graphics/Visualization/Graph
Requires:       %{name}
Requires(post): %install_info_prereq
Requires(preun): %install_info_prereq
BuildArch:      noarch

%description doc
GNUplot documentation files including the man and info pages. GNUplot
is a command line driven interactive function plotting utility. 
GNUplot supports many different types of terminals, plotters, and
printers (including many color devices and pseudodevices like LaTeX)
and can easily be extended to include new devices.

%{name} documentation files including the man and info pages

%prep
%setup -qa 4
bunzip2 -dc %{_sourcedir}/gnuplot-fr.doc.bz2 > docs/gnuplot-fr.doc
test $? -eq 0 || exit 1
cp %{_sourcedir}/picins.sty docs
%patch2 -p0 -b .font
%patch4 -p0 -b .demo
%patch0 -p1 -b .0
%patch1 -p0 -b .x11ovf
%patch5 -p1 -b .w3x
%patch6 -p0 -b .pic
%patch7 -p1 -b .gd
%patch8 -p0 -b .sec
%build
autoreconf -fi

    SECSVGA="-DSVGA_IS_SECURE=1"
    export  CPPFLAGS="-I%{_x11inc} -I%{_includedir}/gd -DAppDefDir=\\\"%{_appdef}\\\""
    export  CPPFLAGS="$CPPFLAGS -DGNUPLOT_LIB_DEFAULT=\\\"%{_docdir}/%{name}/demo\\\""
    export  CFLAGS="${RPM_OPT_FLAGS} -pipe ${SECSVGA} -D_GNU_SOURCE"
    export  CXXFLAGS="$CFLAGS -fno-strict-aliasing"
    export  LDFLAGS="-L%{_x11lib} -Wl,--as-needed"
    export  ARCHLIB=%_lib
    for f in docs/makefile*; do
	test -e $f || continue
	mv $f $f.bak
    done

    autoreconf -fi
#    sed -i "s;bin/uic;bin/uic-qt5;g" ./configure
#    sed -i "s;bin/moc;bin/moc-qt5;g" ./configure
#    sed -i "s;bin/rcc;bin/rcc-qt5;g" ./configure
#    sed -i "s;bin/lrelease;bin/lrelease-qt5;g" ./configure
#    sed -i "s;UIC=uic;UIC=uic-qt5;g" ./configure
#    sed -i "s;MOC=moc;MOC=moc-qt5;g" ./configure
#    sed -i "s;RCC=rcc;RCC=rcc-qt5;g" ./configure
#    sed -i "s;LRELEASE=lrelease;LRELEASE=lrelease-qt5;g" ./configure

    %configure	\
  --enable-stats \
	--with-x		\
	--x-includes=%{_x11inc}	\
	--x-libraries=%{_x11lib}\
	--with-x-app-defaultdir=%{_appdef}\
	--with-texdir=/usr/share/texmf/%{_gnplttex} \
	--with-readline=gnu	\
	--enable-history-file	\
	--with-linux-vga	\
	--with-bitmap-terminals	\
	--with-gpic		\
	--with-mif		\
	--enable-x11-mbfonts	\
%if ! %{with h3d_gridbox}
	--enable-h3d-quadtree	\
	--disable-h3d-gridbox	\
%else
	--disable-h3d-quadtree	\
	--enable-h3d-gridbox	\
%endif
	--enable-backwards-compatibility\
	--with-gd=%{_usr}		\
	--without-row-help	\
	--with-kpsexpand	\
	--with-caca		\
	--with-qt=qt%{qtver}

%if %{qtver} >= 5
  make %{?_smp_mflags} UIC=/usr/bin/uic-qt5  MOC=/usr/bin/moc-qt5 RCC=/usr/bin/rcc-qt5 LRELEASE=/usr/bin/lrelease-qt5 
%else
  make %{?_smp_mflags}
%endif

  pushd docs/
	make srcdir=. clean all html pdf
	make srcdir=. gnuplot.texi
	patch -p0 < %{S:6}
	make srcdir=. info
	pushd psdoc/
	    make srcdir=. pdf
	popd
  popd
  pushd tutorial/
	make srcdir=. clean pdf
  popd
  pushd lisp/
        for el_file in gnuplot.el gnuplot-gui.el; do
            emacs -batch -q -no-site-file -l "dot.el" -f batch-byte-compile \
                  "$el_file"
        done
 popd

%install
    rm -rf %{buildroot}
    make DESTDIR=%{buildroot} appdefaultdir=%{_appdef} install
    mkdir -p %{buildroot}/%{_infodir}
    mkdir -p %{buildroot}/%{_mandir}/ja/man1
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/doc
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/doc/html
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/demo
    mkdir -p %{buildroot}/%{_datadir}/emacs/site-lisp
    rm  -vf docs/htmldocs/images.{aux,idx,log,out,tex}
    rm  -vf docs/htmldocs/*.pl
    rm  -vf docs/htmldocs/*.sty
    rm  -vf docs/htmldocs/WARNINGS
    rm  -vf docs/htmldocs/VERSION
    rm -rvf demo/html
    install -m 0444 docs/*.info*      %{buildroot}/%{_infodir}/
    install -m 0444 docs/*.pdf        %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/htmldocs/*   %{buildroot}/%{_docdir}/gnuplot/doc/html
    install -m 0444 docs/psdoc/*.pdf  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.ps   %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.gpi  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.doc  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/README %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 tutorial/*.pdf    %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 demo/*.*          %{buildroot}/%{_docdir}/gnuplot/demo/
    install -m 0444 README*           %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 Copyright         %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 VERSION           %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 NEWS BUGS	      %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 %{SOURCE3}        %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 lisp/gnuplot*.el* %{buildroot}/%{_datadir}/emacs/site-lisp/
    mv %{buildroot}/%{_mandir}/man1/gnuplot-ja.1 %{buildroot}/%{_mandir}/ja/man1/gnuplot.1
    rm -f %{buildroot}/%{_docdir}/gnuplot/demo/Makefile*
    %fdupes -s %{buildroot}

%post doc
%install_info --info-dir=.%{_infodir} .%{_infodir}/%{name}.info.gz

%preun doc
%install_info_delete --info-dir=.%{_infodir} .%{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%{_bindir}/gnuplot
%{_libexecdir}/gnuplot
%{_datadir}/gnuplot
%{_datadir}/texmf/%{_gnplttex}/
%{_datadir}/emacs/site-lisp/
%{_appdef}/Gnuplot

%files doc
%defattr(-,root,root,-)
%doc %{_docdir}/gnuplot/
%doc %{_infodir}/%{name}.info.gz
%doc %{_mandir}/man1/gnuplot.1.gz
%doc %{_mandir}/ja/man1/gnuplot.1.gz

%changelog
* Wed Nov 28 2018 Dr. Werner Fink <werner@suse.de>
- Add patch gnuplot-e3cc539c.patch from upstream commit e3cc539c
  Fix the bugs boo#1117463 (CVE-2018-19492), boo#1117464 (CVE-2018-19491),
  and boo#1117465 (CVE-2018-19490)
* Thu Feb 15 2018 werner@suse.de
- Do not miss gpic and mif
- Even if pulled by other packages do explicite require for the build
  * pkgconfig(freetype2)
  * pkgconfig(libjpeg)
  * pkgconfig(libpng16)
* Mon Feb 12 2018 crrodriguez@opensuse.org
- Do not use xorg-x11-* as buildrequires
- Fix broken GD libs detection (gnuplot-gd.patch)
- Remove unneeded buildrequires.
* Thu Nov 16 2017 werner@suse.de
- Update to gnuplot 5.2.2
  * NEW splot ... with lines title at {beg|end}
  * FIX allow mixed use of in-key plot titles and manually placed titles
  * FIX prevent runaway iterations of the form   plot for [i=start:*] ...
  * FIX handle in-line range limits for linked or nonlinear axes
  * FIX restore pre-5.2 interpretation of logscaled tic increment as a multiplier
  * FIX logscale tic placement is closer to that of versions before 5.2.0
  * FIX recheck inrange/outrange points after spline or bezier smoothing
  * FIX sampling on x2 if linked to x1;  e.g. plot sample [t=1:5:1] '+' axes x2y1
  * FIX empty range on logscale y axis is handled by auto-extending the range
  * FIX autoscaling xrange of stacked histograms
- Add now missed TEXDIR at configure time which now includes also
  the sub path tex/latex/gnuplot/ below /usr/share/texmf/ (could
  become removed with some of the next version updates?)
* Wed Nov  8 2017 nico.kruber@gmail.com
- Update to gnuplot 5.2.1
  * NEW set table separator {tab|comma|"char"} allows creation of csv files
  * NEW hotkey for changing azimuth in 3D plots with mousing
  * NEW titles for "splot .. with lines" can be placed at {beg|end} of plotted line
  * NEW Rework gstrptime() to handle relative time formats tH tM tS
  * NEW command 'set rgbmax <value>' controls interpretation of input RGB values
  * CHANGE restore pre-5.2 interpretation of logscaled tic increment as a multiplier
  * CHANGE allow mixed use of in-key plot titles and manually placed titles
  * FIX autoscaling of plots with spline or bezier smoothing
  * FIX autoscaling of plots with linked axes where data is plotted on x2 or y2
  * FIX "with filledcurves below y=foo" mishandled the case of y value exactly = foo
  * FIX [windows] repair breakage of stderr/stdout redirection to console
  * FIX postscript terminal artifacts when drawing dot/dash circles
  * FIX handle empty range on logscale y axis as a warning, not an error
* Fri Sep 29 2017 werner@suse.de
- Add patch gnuplot-5.2.0-texi2info.patch as source to be avble
  to patch the resulting gnuplot.texi
- Modify patches
  * gnuplot-4.4.0-x11ovf.dif
  * gnuplot-4.6.0-demo.diff
  * gnuplot-4.6.0-fonts.diff
  * gnuplot-4.6.0.dif
  * gnuplot-QtCore-PIC.dif
  * gnuplot-wx3.diff
* Wed Sep 27 2017 werner@suse.de
- Update to gnuplot 5.2.0
  * NEW user-defined dashtypes in metapost terminal
  * NEW datablock contents may be accessed as an indexed array of strings
  * CHANGE allow explicit sample interval for u and v using pseudofile '++'
  * CHANGE decouple cbrange from color components in "with rgbimage"
  * FIX reconcile aspect ratio flags from "set view map" and "set view equal xy"
  * FIX "set key fixed" should be ignored in the case of "set view map"
  * FIX GPVAL_* variables were not being updated in "set table" mode
  * FIX evaluation of nested iteration containing an empty range
  * FIX bug in variant time_spec formats %%tH %%tM (undesired wrapping)
  * NEW "plot with table" can handle string-valued output columns
  * CHANGE add caca terminal documentation to the user manual
  * CHANGE revised output of "test" command
  * CHANGE use Mingw-w64 and MSVC popen rather than built-in "fake" popen
  * FIX copy environmental variable GNUTERM to internal variable on entry
  * FIX more consistent handling of plot 'with table'
  * FIX incorrect, possibly empty, command string was saved for previous fit
  * FIX ignore non-numeric values of potential dummy params used by "fit"
  * FIX autoscaling during refresh of volatile data plots "with vectors"
  * FIX terminal initialization must be done before executing ~/.gnuplot
  * FIX do not use LaTeX formatting in tabular output
  * FIX polar border should not be clipped to rectangular border
  * FIX raxis was truncated at R=0 if the axis direction was inverted
  * FIX sanity check to catch "plot '+' binary"
  * FIX sanity check for NULL format passed to gprintf
  * FIX sanity check inverse mapping function of set link and set nonlinear
  * FIX sanity check for empty image data structure
  * FIX segfault from corruption of timestamp text
  * FIX several unitialized variables (see Bug 1933)
  * FIX dumb term: linetype character distinction was lost if not in color mode
  * CHANGE svg terminal option "fontscale" replaces obsolete "fsize"
  * NEW plot styles
  * NEW    splot ... using <x>:<y>:<z>:<zlow>:<zhigh> with zerrorfill
  * NEW    "set jitter" allows creation of bee swarm plots
  * NEW    data filter "bins" sorts input into equal width bins on x
  * NEW    "with points" and "with linespoints" accept `pointtype variable`
  * NEW    hidden3d now treats 'image' and 'rgbimage' as occluding rectangles
  * NEW    "smooth fnormal" normalized frequency
  * NEW polar mode improvements and extensions
  * NEW    "set [m]ttics" places labels around perimeter of polar grid
  * NEW    "set rlabel" places a label above the r axis
  * NEW    "set rrange [90:0]" plots in celestial horizontal coordinates
  * NEW    "set border polar" uses border linetype for perimeter of polar plot
  * NEW    "set theta <origin> <sense>" orientation of polar coordinate theta
  * NEW    label, arrow, and object positions may be given in polar coordinates
  * NEW nonlinear coordinate systems
  * NEW    "set nonlinear <axis> via f(axis) inverse g(axis)"
  * NEW    "set log" re-implemented as special case of "set nonlinear"
  * NEW data type array[size]
  * NEW commands and command options
  * NEW    "break" exits from iteration loop
  * NEW    "continue" begins next iteration immediately
  * NEW    "toggle {<plotno> | "plottitle" | all}"
  * NEW    "set pm3d lighting" specifies lighting model with specular highlighting
  * NEW    "set table OUTFILE {append}"
  * NEW    "set minussign" and "set micro" (first appeared in 5.0.5)
  * NEW    "set view azimuth <angle>" controls azimuth of the z axis in 3D plots
  * NEW    "save fit <filename>" replaces deprecated command "update"
  * NEW terminals and terminal options
  * NEW    terminal domterm (supports in-line SVG in DomTerm terminal emulator)
  * NEW    terminal sixelgd (sixel terminal graphics using gdlib)
  * NEW    svg 'standalone' embeds images rather than including by reference
  * NEW    windows terminal supports saving graph as bitmap
  * NEW    windows graph windows can be docked to the wgnuplot text window
  * NEW    windows terminal Direct2D driver rather than GDI/GDI+ where possible
  * NEW    wxt supports saving graph as EMF on Windows
  * NEW    wxt supports printing on Windows
  * NEW    dumb suports ANSI colors and filled polygons
  * NEW Optional sampling interval in range specifiers for pseudofiles '+' '++'
  * NEW gnuplot on Windows
  * converts Unicode (BMP) input to current `set encoding`, including UTF-8
  * is system DPI aware
  * NEW textbox style supports fillcolor and bordercolor
  * CHANGE point style associated with "plot with labels" is shown in the key
  * CHANGE Revise placement of axis labels in 3D plots
  * CHANGE Timestamp is now placed relative to page rather than plot boundary
  * CHANGE Track font/enhanced for key title separately from the key entries
  * CHANGE order of margins in `set margins <left>, <right>, <bottom>, <top>`
  * CHANGE Store and reuse x,y dimensions from the time image data is read in
  * CHANGE Some STATS_* variables are of type integer rather than real (complex)
  * CHANGE ^R starts a backward search when using the built-in readline
  * CHANGE Only update axis->data_min/max if the point being stored is INRANGE
  * CHANGE auto-generation of minitics on logscale axis has changed
  * CHANGE revised printing dialogs on Windows
  * CHANGE preserve whitespace following opening { in enhanced text strings
  * CHANGE windows terminal provides better oversampling
  * CHANGE New default "set key fixed" prevents 3D key box from rotating with plot
  * CHANGE Deprecate pdf terminal requiring non-free library PDFlib
  * CHANGE windows terminal also uses GDI+ for printing and copy-to-clipboard
  * CHANGE raxis/polar grid can coexist with cartesian axes
  * CHANGE evaluation of norm(x) or x**y returns 0 on floating underflow
  * CHANGE support for space-in-x11-raises-KDE3-konsole is now a configure option
  * CHANGE don't use loadpath to choose output directory for "save"
  * CHANGE GNUTERM may contain terminal options in addition to bare terminal name
  * CHANGE remove legacy terminals corel and dxf from default build
  * FIX cairo.trm - reset terminal font after printing an enhanced text string
  * FIX autoscaling of data with "smooth cnorm"
  * FIX Built-in readline handles S-JIS encoding
  * FIX Output to printer on Windows via special file "PRN"
* Wed Aug 16 2017 werner@suse.de
- Update to 5.0.7 (which does also close CVE-2017-9670 (bsc#1044638))
  * NEW set term {pngcairo|pdfcairo} pointscale <factor>
  * NEW "save fit" back-ported from version 5.2 as a replacement for "update"
  * NEW user-defined dashtypes in metapost terminal
  * CHANGE deprecate "update" command (but do not remove it)
  * CHANGE allow placement of circles in 3D plots using axis coordinates
  * CHANGE ignore invalid z coordinate for 3D objects placed in "set view map"
  * CHANGE distinguish 'bind "shift-Button1"' from 'bind "Button1"'
  * CHANGE use Mingw-w64 and MSVC popen rather than built-in "fake" popen
  * CHANGE allow range to include sampling interval in plots using pseudofile '+'
  * FIX rangelimited y2 axis could produce spurious diagonal line across plot
  * FIX assignment of x/y dimensions in "binary record=(a,b) ... with image"
  * FIX negative array index caused by hidden3d degenerate polygon
  * FIX object clipping in "set view map"
  * FIX cairo terminals: scale textbox border linewidth by terminal linewidth
  * FIX canvas terminal: initialization of plot dimensions (affects first zoom)
  * FIX crash in stats if no usable data is found
  * FIX do not use LaTeX formatting in tabular output
  * FIX sanity check to catch "plot '+' binary"
  * FIX sanity check for NULL format passed to gprintf
  * FIX sanity check for empty image data structure on input
  * FIX more consistent handling of plot 'with table'
  * FIX incorrect, possibly empty, command string was saved for previous fit
  * FIX 2D images with logscale axes could fail (segfault)
  * FIX nested iteration containing an empty range
  * FIX allow 64-bit Cygwin build using gtk3 for wxt terminal
* Wed May 10 2017 nico.kruber@gmail.com
- Update to 5.0.6
  * NEW command 'set micro' enables encoding-specific char for gprintf %%c format
  * NEW command 'set datafile missing NaN' treats invalid data as if it were
    missing
  * NEW backport updated svg/domterm terminal from development version
  * CHANGE - start/end limits in nested iterations are reevaluated dynamically
  * CHANGE - revised adjustment of x2label and plot title when x2tics are
    present
  * CHANGE - mark non-free pdf terminal DEPRECATED
    (to be removed in release 5.2)
  * CHANGE - allow fractional font sizes for gdlib terminals
  * CHANGE - do not allow inverted R axis
    (requires support not backported from 5.1)
  * CHANGE - allow pointinterval property in 'with lp' for splot as well as
    for plot
  * CHANGE - "linewidth <lw>" is accepted as a terminal option for aquaterm,
    qt, wxt
  * CHANGE - spline segments outside xrange are ignored rather than treated
    as errors
  * FIX wxt - multithreaded wxt was faulting during resize (mutex lock failure)
  * FIX windows - timed pause only worked for intervals < 1 second
  * FIX Front/back layering of border+grid lines was not always correct in
    hidden3d
  * FIX "set pm3d depthorder interpolate N,M" memory allocation failure
  * FIX aquaterm failed to honor request to disable enhanced text markup
  * FIX save and show commands failed to list linecolor for lines with "lt -1"
  * FIX the "missing" data flag is honored by "using ($n)" as it is for "using n"
  * FIX error reporting of line number inside a bracketed clause
  * FIX gnuplot_x11: possible fix for sporadic use-after-free error
  * FIX initialization of hidden3d structures for splot with dots
  * FIX track arrowhead properties in hidden3d mode
  * FIX tracking of NaN values from function evaluated during binary data input
  * FIX 3D rotation does not clobber hidden/visible status of plots
* Thu Dec 15 2016 werner@suse.de
- Update to 5.0.5
  * NEW allow filename completion for system commands and pipes (backport from 5.1)
  * NEW option to plot with labels {rotate variable}
  * NEW command "set minussign"
  * NEW stats command "name" option now accepts "columnheader" or "columnheader(N)"
  * NEW command option "set colorbox invert"
  * CHANGE qt terminal force selection of outline font rather than bitmap font
  * CHANGE post terminal simplex/duplex output depends on PostScript level setting
  * CHANGE improved autoscaling of plot "with boxes"
  * CHANGE qt terminal sets TERM_POLYGON_PIXELS to avoid aliasing artifacts
  * CHANGE all stats and fit commands skip header records if "autotitle columnhead"
  * FIX Do not confuse EOF with 8-bit character 0x177 (E.g. in Cyrillic encodings).
  * FIX use blank line rather than 'u' flag in "set table" output of smoothed data
  * FIX order dependence of "fillcolor" keyword in plot commands
  * FIX svg - better vertical justification of rotated text
  * FIX wxt - file export widget correctly handles inactive plots
  * FIX qt - preserve leading and trailing whitespace in enhanced text strings
  * FIX various bugs affecting matrix data plotted "with image"
- Remove the patches now upstream
  gnuplot-5.0.0-lua-5.3.1.dif
  gnuplot-5.0.1-fix-latex-docs.diff
- Port patches to current version
  gnuplot-4.4.0-x11ovf.dif
  gnuplot-4.6.0-demo.diff
  gnuplot-4.6.0.dif
  gnuplot-QtCore-PIC.dif
  gnuplot-wx3.diff
* Tue Jul 26 2016 werner@suse.de
- Some more TexLive packages
* Mon Nov 30 2015 nico.kruber@gmail.com
- Update to 5.0.1
  * NEW "set mono" (full command "set monochrome {linetype lt
    <line-properties>}")
  * NEW "set fit nolog" suppresses output to log file
  * NEW sixel terminal supports RGB and palette colors, but only 16 at
    a time :-(
  * NEW command "printerr" acts exactly like "print" but always outputs
    via stderr
  * CHANGE autoconfigure of Qt5 support now looks for --variable=host_bins
  * CHANGE reevaluate fill color for each polygon in data for
    "with filledcurves"
  * CHANGE gstrptime(): always check validity of %%y %%Y %%d %%B %%b input fields
  * CHANGE track text properties for key title separately from key entries
  * CHANGE "smooth kdensity" now handles logscale y and explicit x range
  * CHANGE order of margins in the "set margin" command to left, right,
    bottom, top
  * CHANGE guarantee color of key sample for "lc variable" plots matches
    1st point
  * CHANGE "set term fig color" can use predefined linetype colors and
    named colors
  * CHANGE skip all preprocessing for input lines beginning with shell escape
    char
  * CHANGE build system to suppress dvi as an automake-generated target
  * CHANGE in hidden3d mode, the 'nosurface' suppresses both surface grid
    directions
  * FIX replace palette color value NaN with background color
  * FIX improved handling of boxplot data with multiple factors (categories)
  * FIX save_textcolor was not handling "tc variable"
  * FIX apply numeric locale when reading ascii matrix data
  * FIX handling of ascii matrix data
  * FIX reinitialize brush used to draw dotted lines in gd terminal
  * FIX failure to clear bold/italic text attributes in cairo terminals
  * FIX tabular output of time data when the axis format has not been set
  * FIX breakage in plot style filledcurves {above|below} y1=<yval>
  * FIX dashtypes after "set term {e}pslatex mono"
  * FIX report and enforce maximum number of parallel axes without faulting
  * FIX smooth mcsplines for a curve containing multiple y values at a single x
  * FIX several bugs evident for log-scaled color axis
  * FIX regression in color support for pbm/sixel/hpgl terminals (no RGB color)
  * FIX accummulated round-off error in dotted lines drawn by libgd terminals
  * FIX incorrect colorbox axis labels in polar plots
  * FIX AquaTerm framework name is case-sensitive
  * FIX strip enhanced text markup from plot titles embedded in svg output
  * FIX error in retrieving matrix column headers as strings
  * FIX error in calculating absolute deviation (stats command)
  * FIX allocation error from "set fit covariancevariables"
  * FIX tkcanvas terminal handling of blank (default) font family name
  * FIX off-by-one-error in color of contours when hidden3d is active
  * FIX adjust WIN32 encoding used by text output from "pause" command
  * FIX qt terminal 3D rotation mode tendency to get stuck "on"
  * FIX dash pattern rendering in contour lines
  * FIX 'fit [][min:max] f(x)' was incorrectly ignoring min:max
- Rediff gnuplot-4.6.0.dif
- Add gnuplot-5.0.1-fix-latex-docs.diff to fix a regression of 5.0.1 in
  building the latex docs
* Tue Jul 28 2015 werner@suse.de
- Add patch gnuplot-5.0.0-lua-5.3.1.dif to make it build with
  lua-5.3.1
* Fri Jul 24 2015 werner@suse.de
- Require pkgconfig of libcerf at build time
* Fri May 22 2015 werner@suse.de
- Make it build even with older Qt4 based systems
* Thu May 21 2015 werner@suse.de
- Since QtCore is build with -reduce-relocations a -fPIC is required
  therefore add patch gnuplot-QtCore-PIC.dif
* Sun Mar 22 2015 jengelh@inai.de
- Enable CACA output module
- Build with wxWidgets 3. Add patch gnuplot-wx3.diff
* Sat Jan 31 2015 alinm.elena@gmail.com
- for versions greater than 13.1 we shall build against qt5
  * cleaned up various rpmlint warning
  * got rid of configure options obsoleted
* Wed Jan 21 2015 burnus@net-b.de
- Update to 5.0.0
  * NEW new command set {xyz}tics {timedate|geographic|numeric} sets
  axis->tictype
  * NEW add the tictype keywords to
  set format {axis} {time|geographic|numeric}
  * NEW format modifier 't' in timedate mode indicates a time
  rather than a date
  * NEW grey out key entries when corresponding plot is toggled off
  * NEW allow parenthesized expressions as call parameters
  * NEW set margins <left>, <right>, <top>, <bottom>
  * NEW set trange [theta_min:theta_max] filters input data in polar plots
  * NEW "set mouse zoomfactors <xfact>,<yfact>"
  * NEW New matrix keywords for text data: "columnheaders" and "rowheaders"
  * NEW The dashtype property on any line can be seperately controlled
  * NEW custom dashtypes
  * NEW LFS support for datafiles
  * NEW timecolumn(col,"timeformat') now requires 2nd parameter, the format
  * NEW 'set view map {scale}' allows resizing a 3D projection plot
  * NEW 'nodraw' keyword to suppress lines (e.g. in style linespoints)
  * NEW bold/italic text markup in enhanced text mode
  * NEW bit-shifing binary operators << and >>
  * NEW stat calculates skewness, kurtosis, and standard errors
  * NEW function plugins, e.g. 'import f(x) from "plugins.so"'
  * NEW option to tabulate all input columns "set table;
  plot ... with table"
  * NEW smoothing option "mcsplines" for piecewise monotonic
  cubic splines
  * NEW 'history !N' reexecutes the command at history entry N.
  * NEW 'set history {size <N>} {quiet|numbers} {full|trim} {default}'
  * NEW piecewise functions via separate sampling ranges for each plot
  element
  * NEW function hsv2rgb(H,S,V) creates a 24-bit RGB value
  * NEW plot title can be placed next to the plot line in
  the graph proper
  * NEW inline data can be stored for reuse in named data blocks
  * NEW 'set print|table $datablock' to redirect output to a named
  data block
  * NEW hypertext labels can be displayed on mouse-over
  * NEW geographic (Degrees Minutes Seconds) data axes
  * NEW set arrow <tag> from <start> length <len> angle <ang>
  * NEW arrow style keywords "noborder" and "fixed"
  * NEW the high bits of RGB colors are treated as an alpha channel
  * NEW 'set surface explicit' disables automatic generation of
  a surface mesh
  * NEW 'set link [x2|y2]' ties secondary axis range to the primary axis
  * NEW 'set link x2 via f(x) inverse g(x)' introduces generic nonlinear
  axes
  * NEW linked axes can be used to place x2 and y2 labels on 3D plots
  in map mode
  * NEW 'set key opaque' works for 3D plots also
  * NEW x11 terminal is aware of current and requested plot aspect ratio
  * NEW x11 support for toggling plots on/off with left mouseclick on
  the key
  * NEW post term can use /FlateDecode to reduce the size of embedded
  images
  * NEW 'set fit quiet|results|brief|verbose' changes fit's verbosity
  * NEW fit optionally stores final covariances to user variables
  * NEW fit command takes errors of independent variables into account
  * NEW 'set multiplot next/previous'
  * NEW 'set contours; splot FOO with labels' places labels on the
  contour lines
  * NEW Additional levels of user-specified axis tics
  * NEW complex math routines cerf, cdawson, erfi, faddeeva from
  libcerf if present
  * NEW i/v/V hotkeys to toggle all plots on the screen on/off
  * NEW 'set mrtics' (minor tics on polar axis)
  * NEW 'reset session'
  * NEW call argument convention ARGC, ARG0 ARG1 ... ARG<ARGC>
  * NEW shell invocation gnuplot -c scriptfile ARG1 ARG2 ARG3
  * NEW format %%h is like %%g but uses LaTeX or enhanced markup for the
  exponent
  * NEW LaTeX terminals use math mode for axis tic labels
  * NEW Interrupt scripts or fits by pressing Ctrl-C in Windows console
  mode gnuplot or Ctrl-Break in wgnuplot.
  * NEW optional faster windows terminal variant using GDI+
  * NEW plot option to "skip N" lines at start of an ascii data file
  * NEW interactive color character art terminal "caca"
- Rediff gnuplot-4.6.0-fonts.diff, gnuplot-4.4.0-x11ovf.dif,
  gnuplot-4.6.0.dif and gnuplot-4.6.0-demo.diff.
- Remove gnuplot-4.6.0-backtick.diff as to-be-patched file no longer
  exists.
* Tue Oct 28 2014 kruber@zib.de
- Update to 4.6.6
  * NEW linetype keyword "nodraw" can be used to draw only the points in
    "with lp"
  * NEW plot option to "skip N" lines at start of an ascii data file
  * NEW 'set fit prescale' normalized fit parameters before M-L refinement
  * NEW update svg terminal to grey out the key entry when a plot is
    toggled off
  * NEW allow keywords "comma" and "tab" for "set datafile separator"
  * CHANGE Accept "with image pixels" as a synonym for "with image failsafe"
  * CHANGE return NaN if a requested numerical data value finds a string
    instead
  * CHANGE Consume only one space following the font name in an enhanced
    test string
  * CHANGE respond to left mouse click on press rather than on release
  * FIX Faster recovery from outboard server gnuplot_qt being killed
  * FIX get rid of O(N^2) memory allocation for string data in long input
    lines
  * FIX large integers in iteration spec could cause overflow in end
    condition check
  * FIX object fillcolors should be consistent with the color of current
    linetypes
  * FIX LFS support on 64bit platforms (not backported for 32bit platforms)
  * FIX timecolumn() applied to non-axis data reports an error rather than
    faulting
  * FIX clipping could fail on integer overflow
  * FIX segfault resulting from strcol(N) applied to empty field in a *.csv
    file
  * FIX adjustment of key size to accommodate long key title
  * FIX treat data value read as "NaN" the same as we would "1/0"
  * FIX handling of events triggered by closing the qt plot window
  * FIX iteration failure due to integer overflow
  * FIX clip r axis tics to current plot boundary
  * FIX logscale cb axis with volatile data
  * FIX qt terminal timing problem with mouse click+release
  * FIX qt terminal handle window close events
  * FIX incorrect processing of certain loop [start:end:incr] combinations
  * FIX Fix y extent and clipping of rectangles with y coord < 0 or inverted
    axes
  * FIX handle columnheaders in input to fit
  * FIX add sanity check in pdf.trm to avoid strcpy(fontname,fontname)
* Tue Feb 25 2014 burnus@net-b.de
- Update to 4.6.5
  * NEW monotonic cubic splines using "smooth mcsplines"
  * NEW phase-jump removal filter "smooth unwrap"
  * NEW allow '+' pseudofile to sample the T axis in 2D parametric
    plots
  * NEW allow '++' pseudofile to sample the U/V axes in 3D
    parametric plots
  * NEW "sixel" terminal driver
  * NEW new object attribute clip/noclip
  * CHANGE maximum number of using spec columns increased from 7
    to 11
  * CHANGE code in bitmap.c relicensed to remove restriction to
    noncommercial use
  * FIX allow 'set pm3d' interpolate and top/bottom options to
    coexist
  * FIX revised handling of defined palettes with explicit
    maxcolors
  * FIX continue as normal after an interactive session error
    from "gnuplot -"
  * FIX empty first field in a tab-separated-values file was
    incorrectly ignored
  * FIX several problems with color assignment to contour lines
  * FIX qt terminal incorrectly changed linetype (dot/dash)
    to match line color
  * FIX "pause mouse" worked only for right- or center- click,
    not left-click
  * FIX emf terminal font initialization
  * FIX wxt terminal vertical centering of enhanced text
  * FIX win terminal filled polygon bugs
  * FIX iteration over parametric function plots
  * FIX autoscaling of polar mode plots
  * FIX increase precision of xticlabel placement from (float) to (double)
  * FIX allocation error affecting certain cvs files
* Tue Oct 29 2013 burnus@net-b.de
- Update to 4.6.4
  * CHANGE treat empty fields in a csv file as "missing" rather than "bad"
  * CHANGE allow reference to more than one column header in 'using' or 'title'
  * CHANGE if a polar plot is autoscaled, try to place the origin at the center
  * FIX svg and canvas terminal mousing of inverted axis coordinates
  * FIX emf failed to initialize font correctly on some systems
  * FIX timedata columns can now be referred to via column(N) and column("HEAD")
  * FIX qt terminal toggling of enhanced text elements in plot with labels
  * FIX color/pattern generated for key entries of columnstacked histograms
  * FIX hitting ^C twice forces temination of wxt session hung by lost X-server
  * FIX win terminal failed to properly adjust plot border after window resize
  * FIX several conditions in which macros were not expanded during command input
  * FIX promote a string containing only digits to INTGR rather than CMPLX
  * FIX 'set grid front' caused failure to initialize location of axis zero point
  * FIX very poor precision in mouse coords reported by x11 in -persist mode
  * FIX parsing of $# (the number of arguments in a "call"). It's not a comment!
  * FIX memory leak of cropped images using pngcairo terminal
  * FIX "lc variable" now iterates over linetype colors (not styles) as documented
  * FIX rtics were sometimes drawn with length 0
* Thu Apr 25 2013 burnus@net-b.de
- Update to 4.6.3
  * FIX suppression of color in linetypes after "set term ... mono"
  * FIX synchronization of graphics and text color in latex terminals
* Sun Mar 31 2013 burnus@net-b.de
- Update to 4.6.2
  * Bug fixes
  * Allow the "bind" command to attach a user command to
    mouse button 1
  * hidden3d can handle occlusion by pm3d surfaces
  * -d option from command line skips ~/.gnuplot
    initialization file
  * plot '<&N' plots from file descriptor N opened during
    shell invocation
* Tue Nov  6 2012 burnus@net-b.de
- Update to 4.6.1
  * Bug fixes.
  * Support tabulation of variable color column.
  * Support tabulation (set table) of pixel values from image plot
    styles
- Remove now obsolete patches gnuplot-automake.diff and
  gnuplot-4.6.0-fix-format-errors.diff.
* Tue Oct 16 2012 coolo@suse.com
- buildrequire libpng, it compiles fine with it
* Mon Jul 23 2012 werner@suse.de
- Resolve the former problem by using texlive-texinfo to enforce
  installing required fonts as well as required tools for TL 2012
* Sun Jul 22 2012 coolo@suse.com
- add more texlive 2012 requirements
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
* Tue Jul  3 2012 werner@suse.de
- Convert gnuplot.el to new backtick lisp scheme for emacs 24.1
* Wed May 30 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Add patch to delete no-longer supported constructs from
  configure.in/Makefile.am
* Wed Apr  4 2012 werner@suse.de
- Use new bcond_without h3d_gridbox to switch back to h3d-quadtree
  if h3d-gridbox will be disabled on the commandline of rpmbuild
* Mon Apr  2 2012 werner@suse.de
- Avoid to stumble on bug in QtCore.pc on older distributions
* Mon Apr  2 2012 werner@suse.de
- Refresh patches to see in which C function each change is in
- Reenable bitmap terminals
* Thu Mar 15 2012 kruber@zib.de
- Update to gnuplot 4.6.0
  * New syntax supporting multi-line blocks of code delimited by curly braces
    if (<cond>) { ... } else { ... }
    do for [<iteration-spec>] { ... }
    while (<cond>) { ... }
  * Time formats can handle fractional seconds to microsecond precision.
  * User-definable linetypes that can be used to establish a locally
    preferred default sequence of colors or dash/thickness/point styles.
  * Statistical summary of the data to be plotted (new command "stats")
  * New terminal drivers:  qt  context  epscairo  cairolatex
  * The version for Windows received major improvements
    (GUI, help, native terminal and wxt, installer)
  * Improved support for UTF-8, SJIS and other multi-byte encodings
* Mon Feb 13 2012 burnus@net-b.de
- Make gnuplot build with newer LUA version.
* Mon Feb 13 2012 werner@suse.de
- Fix version control of further help messages, fix done
  by Dieter Jurzitza (bnc#746299)
* Fri Feb 10 2012 sbrabec@suse.cz
- Fix libdir x libexecdir clash (bnc#744835).
- Use %%configure macro.
* Tue Dec 13 2011 cfarrell@suse.com
- license update: SUSE-Gnuplot and GPL-2.0+
  SPDX format (including SUSE prefix for licenses not yet accepted by SPDX
  upstream). This is not BSD-3-Clause. The Gnuplot license insists that
  modifications to source code be done by patch only. There are GPL-2.0+
  components included as aggegation
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 29 2011 burnus@net-b.de
- Update to gnuplot 4.4.4
  * NEW boxxyerrors plot style now allows variable color
  * NEW splot with pm3d now allows variable rgb color
  * NEW "nonuniform matrix" indicates ascii data with explicit x, y
  * CHANGE columnhead(N) is a string-valued function, not a keyword
  * CHANGE Demarcate plots in svg output using <g id="Plot_#"><title>...
  * CHANGE xticlabels() works for binary data files as well as ascii
  * CHANGE "set key maxrows" now applies to 3D plots as well as 2D
  * CHANGE rewrite installation path rules for TeX files
  * FIX wxt terminal should now work on at least some flavors of OSX
  * FIX incorrect space allowed for outside left key box
  * FIX buffer overflow from enhanced text timefmt tic labels
  * FIX correction for offset in epochs when reading in time format "%%s"
  * FIX discontinuity in defined palette limited by maxcolors
  * FIX initialization of svg pattern-fill definitions
  * FIX positioning of histogram bars when some data entries are missing
  * FIX emf terminal can handle UTF-8 encoding
  * FIX User-specified axis tick labels override auto labels in 3D
    just as in 2D
  * FIX `plot with labels` failed to skip labels with UNDEFINED coords
  * FIX NaN (not a number) implementation for Windows build
  * FIX work-around for poor scaling in pdfcairo pattern fill
  * FIX segfault if mismatch between palette sizes of successive terminals
* Thu Apr 21 2011 burnus@net-b.de
- Update to gnuplot 4.4.3
  * NEW Implement pan and zoom via mouse wheel.
  * NEW set key maxcolumns N maxrows M
  * NEW value("varname") returns the value of the named variable
  * NEW encoding cp1251 - 8-bit Cyrillic
  * CHANGE backport emf terminal driver from version 4.5
  * FIX better estimation of latex string lengths
  * FIX colorbar representation of discrete color palettes is pixel accurate
  * FIX NaN initialization and tests working on more (all?) platforms
  * FIX configuration script tests for readline+ncurses
  * FIX prevent out-of-range boxes from creating degenerate ghosts on the border
  * FIX missing alpha channel flag for pdfcairo terminal
  * FIX font initialization in windows terminal
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Thu Sep 30 2010 burnus@net-b.de
- Update to gnuplot 4.4.2
  * Fixes a regression that caused color specification "lc N" to fail
  * Fixes a long-standing clipping error in plots with filled curves
  * Fixes a segfault if a "refresh" commands follows an interrupted replot
  Changes and fixes in gnuplot version 4.4.1:
  * NEW Support the "%%s" format specifier in strftime()
  * NEW Optional 6th data column in candlesticks style to specific box width
  * NEW If integer arithmetic i*j or i**j would overflow, return value as a real
  * NEW "set style circle radius <default-radius>"
  * FIX autoconfiguration of readline support in OSX
  * FIX font problems in win terminal
  * FIX Protect against runaway recursion by limiting depth of nested functions
  * FIX metapost terminal: Fix inheritance of line thickness by text strings
  * FIX cairo terminals could segfault on certain enhanced text strings
  * FIX pdfcairo output to stdout now works
  * FIX font ",size" in non-enhanced mode postscript terminals
  * FIX Do a better job of estimating the width of UTF-8 encoded strings
  * FIX baseline bug in canvas terminal rotation of enhanced text
  * FIX Allow "with labels" to work for binary input data
  * FIX update user GPVAL variables after plot in table mode
  * CHANGE depth-sorting of pm3d surfaces now applies jointly to all in the plot
  * CHANGE 3D impulses are now always drawn from z=0
  * CHANGE Enable HIDDEN_QUADTREE by default
  * CHANGE Enable "set fit errorvariables" by default
  * CHANGE Regardless of current timefmt, read time from binary files as a binary
  * CHANGE do not limit 3D rotation to 0<rotx<180
* Tue Sep 14 2010 werner@suse.de
- Make doc package noarch
* Tue Sep 14 2010 werner@suse.de
- Update to gnuplot 4.4.0
  * NEW Support the "%%s" format specifier in strftime()
  * NEW Optional 6th data column in candlesticks style to specific box width
  * NEW If integer arithmetic i*j or i**j would overflow, return value as a real
  * NEW "set style circle radius <default-radius>"
  * FIX autoconfiguration of readline support in OSX
  * FIX font problems in win terminal
  * FIX Protect against runaway recursion by limiting depth of nested functions
  * FIX metapost terminal: Fix inheritance of line thickness by text strings
  * FIX cairo terminals could segfault on certain enhanced text strings
  * FIX pdfcairo output to stdout now works
  * FIX font ",size" in non-enhanced mode postscript terminals
  * FIX Do a better job of estimating the width of UTF-8 encoded strings
  * FIX baseline bug in canvas terminal rotation of enhanced text
  * FIX Allow "with labels" to work for binary input data
  * FIX update user GPVAL variables after plot in table mode
  * CHANGE depth-sorting of pm3d surfaces now applies jointly to all in the plot
  * CHANGE 3D impulses are now always drawn from z=0
  * CHANGE Enable HIDDEN_QUADTREE by default
  * CHANGE Enable "set fit errorvariables" by default
  * CHANGE Regardless of current timefmt, read time from binary files as a binary
  * CHANGE do not limit 3D rotation to 0<rotx<180
* Thu May 20 2010 werner@suse.de
- Correct macro name in spec file
* Tue May 18 2010 dieter.jurzitza@t-online.de
- Fix format being written into plt files (add missing #)
* Sat May  8 2010 dieter.jurzitza@t-online.de
- Fix AppDefDir vs. XAPPLRESDIR inconsistency, increase default number of samples.
* Wed Apr  7 2010 werner@suse.de
- Update to gnuplot 4.4.0
  * NEW linetype property 'pointinterval'
  * NEW gnuplot.exe is a full-featured console mode gnuplot executable for Windows
  * NEW plot style "with circles"
  * NEW object types circle, ellipse, and polygon
  * NEW options front and back to "set colorbox"
  * NEW x11 can plot into a window opened and managed by an external application
  * NEW gd terminal can use fonts through fontconfig (libgd version > 2.0.35)
  * NEW optional 3 columns of data to generate histogram errorbars
  * NEW 'volatile' data, including inline data, can be replotted without rereading
  * NEW 'refresh' command replots without rereading data if possible
  * NEW rgbimage style now works in 2D and 3D for all terminals that support RGB
  * NEW plot style rgbalpha
  * NEW transparent fill styles
  * NEW iteration within a plot command; e.g. plot for [i=1:10] foo(i)
  * NEW iteration within set/unset commands
  * NEW operators '=' and ',' in expression syntax
  * NEW terminal lua generates commands for interpretation by external lua script
  * NEW terminal tikz uses a lua script to generate output for latex TikZ package
  * NEW terminal canvas for HTML 5 canvas element
  * NEW terminal pdfcairo based on cairo and pango
  * NEW terminal pngcairo based on cairo and pango
  * NEW terminal dpu414 - Seiko DPU-414 thermal printer
  * NEW error status variables GPVAL_ERRNO and GPVAL_ERRMSG
  * NEW variables GPVAL_LAST_PLOT, GPVAL_{S}PLOT, GPVAL_MULTIPLOT
  * NEW variables GPVAL_VIEW_{MAP|ROT_X|ROT_Z|SCALE|ZSCALE}, GPVAL_TERMINALS
  * NEW variables GPVAL_PWD
  * NEW per-plot export of information needed for external mousing scripts
  * NEW support for dashed linetypes in additional terminals
  * NEW the 'bind' command accepts non-keyboard triggers, e.g. 'close'
  * NEW commands 'show bind' and 'reset bind'
  * NEW individual plots can be omitted from autoscaling of axis ranges
  * NEW more smoothing options: new kernels (for dgrid3d) and 'smooth cumulative'
  * NEW command 'evaluate' executes commands from a string variable
  * NEW z-axis tic labels can be colored by Z value
  * NEW command 'set view equal {xy|xyz}' forces axes in a 3D plot to the same scale
  * NEW 'set pm3d interpolate m,n' supports also non-positive m,n as nbs of points
  * FIX domain restrictions on ibeta()
  * FIX color assignment of contour lines when "set increment user" is in effect
  * FIX remove the limit of 64 characters read as string data from a data file
  * FIX remainder of command line is not lost after a "load" command
  * FIX more complete support for locale internationalization, UTF-8 encoding
  * FIX various font-handling problems in postscript terminal driver
  * FIX avoid infinite loop on resizing x11 plot window under ion, fluxbox
  * FIX handle addition plot styles in mode 'set table'
  * FIX purge tick labels read from a datafile at the end of each plot
  * FIX 2nd colour in the colour box for negative palette in postscript
  * FIX interpolatation for pm3d surfaces given by both z and colour coordinates
  * FIX 'set datafile binary format=...' was documented, but not implemented
  * FIX enhanced text mode treatment of UTF-8 characters
  * FIX emf terminal enhanced text mode now accepted by Windows programs
  * CHANGE A number that begins with a . must continue with a digit
  * CHANGE syntax of 'set datafile binary' array= and record= options
  * CHANGE 'reset' does not affect locale, encoding, decimalsign settings
  * CHANGE 'set key textcolor rgb variable' will use plot colors for key entries
  * CHANGE Remove obsolete IRIS4D terminal type
  * CHANGE Remove obsolete atari terminal types (atariaes atarivdi multitos)
  * CHANGE Use empty/solid fill for candlesticks rather than empty/striped
  * CHANGE 'l' and 'L' hotkeys toggle colorbar logscale iff mouse is in colorbar
* Thu Mar  4 2010 coolo@novell.com
- fix compilation with gcc 4.5
- update to gnuplot 4.2.6
  * NEW xterm tektronix emulation 'set term xterm'
  * FIX 'set xtics mirror' didn't work if xtics were previously unset
  * FIX off-by-one pixel bug in width of boxes with palette or rgb color
  * FIX center rotation of 'set view equal xyz' mode at screen center
  * FIX sanity-check time ranges for axes with timeformat
  * FIX pslatex blacktext and broken format specifier
  * FIX PostScript code points for Lcaron, lcaron in encoding cp1250
  * CHANGE If a 2D plot uses a Z-based palette, then autoscale cbrange
  * CHANGE aquaterm accepts "size xx,yy" with a comma
  * CHANGE Remove the EXPERIMENTAL flag from the wxt terminal
  * CHANGE Remove the EXPERIMENTAL flag from the x11 terminal binary polygon mode
* Mon Jun 22 2009 werner@suse.de
- Remove obsolate code for GNUPLOTDEMOPATH (bnc#515001)
- Add emacs lisp files to file list (bnc#515001)
* Mon Jun 15 2009 werner@suse.de
- Make demos more flexible (hint from dieter.jurzitza@t-online.de)
- Add netpbm and xorg-x11 to build requires or jpg's are zero
* Tue May 26 2009 werner@suse.de
- Update changes file
* Sat May  9 2009 nico.laus.2001@gmx.de
- update to gnuplot 4.2.5
- put docs into gnuplot-doc sub-package
* Thu Jan 15 2009 sbrabec@suse.cz
- Changed BuildRequires: plotutils -> plotutils-devel.
* Mon Mar 31 2008 werner@suse.de
- Make gnupplot UTF-8 capable (bnc#375175)
* Wed Mar 26 2008 werner@suse.de
- Update to gnuplot 4.2.3
  * NEW options front and back to "set colorbox"
  * NEW character encoding support for emf and pdf terminals
  * NEW "format" keyword for "set tics" and "set {x|y|...}tics"
  * NEW allow user to set colorbar label rotatation if the bar is vertical
  * FIX allow tic format to be given as a string variable
  * FIX handling of negative screen coordinates on ia64, PPC
  * FIX coloring of hidden surfaces if drawn with line styles
  * FIX direction of y axis in graph coords for "set view map"
  * FIX minitics in log scale
  * FIX minor bugfixes to terminals fig, emf, post, svg, x11
  * FIX cgm terminal now produces correct pm3d and pattern fill output
  * FIX protect against overly long font names in gd, svg
  * FIX infinite loop from x11 plot window resizing under ion, fluxbox
  * FIX never estimate zero size for a non-empty string
  * FIX discard degenerate polygons during hidden3d processing
  * FIX segfault if replot is called while terminal type is unknown
  * FIX segfault if locale obtained by getenv() is freed
  * FIX discard axis ticks read from previous data file
  * FIX Do not clip image against Z range in 3D splot with "set view map"
  * FIX off-by-one error in implicit column 0 for binary data files
  * FIX splot was trashing the default clipping boundaries for 2D plots
  * CHANGE tweak installation scripts for OSX nt cyg dj2 mgw
  * CHANGE install Xresource file as Gnuplot, not Gnuplot.app-defaults
  * CHANGE Remove limitation of 10 args max to internal function sprintf()
  * CHANGE Bring emf point types into conformity with other terminals
  * CHANGE estimate the vertical space for rotated tick labels on x and x2 axes
* Fri Mar 14 2008 werner@suse.de
- Disable warning about missing character set to avoid bnc#369156
* Fri Dec 14 2007 werner@suse.de
- Update to gnuplot 4.2.2
  * FIX Axis labels were ignored in mode "set view map"
    Candlesticks did not receive the border color specified in fillstyle
  * NEW allow extra column in 2D plots containing color information
  * NEW set term latex {size XX,YY}
  * FIX buffering of very long input lines
  * FIX clipping of image data against plot boundary
  * FIX polygon clipping bugs
  * FIX key sample for plots with variable color
  * FIX wxt initialization on non-gnu systems
  * FIX escape sequence %%%% handling in sprintf() format strings
  * FIX Apply "set style incr user" to 3D contours and to columnstacked histograms
  * FIX Apply "set key {no}enhanced" to key titles read from a file
  * FIX Allow string variable as filename for "fit via <filename>"
  * CHANGE defer x11 initialization until first plot command
  * CHANGE clean up configuration files for amg, cyg, mgw, dj2
  * CHANGE modify SVG output to accommodate non-compliant viewers
  * CHANGE allow 'strcol()' as shorthand for 'stringcolumn()'
  * CHANGE default to "blacktext" for TeX-based PostScript variants
* Wed Sep  5 2007 werner@suse.de
- Correct name of app-defaults file
- Make samples in demo directory usable from any path
  thanks goes to Dieter Jurzitza
* Wed May 30 2007 werner@suse.de
- Overwrite empty default font for UTF-8 locale (bug #277876)
- Get html docs fully build and installed
- Correct datadir
- The patent of gif is expired
* Fri May 11 2007 werner@suse.de
- Use setlocale(..,NULL) instead of gentenv() (bug #272915)
* Tue Apr 24 2007 werner@suse.de
- Enable new but experimental wxt terminal (bug #266693)
* Fri Apr 20 2007 aj@suse.de
- Use texlive for Building.
* Thu Apr  5 2007 werner@suse.de
- Update to gnuplot 4.2.0
  * NEW autogenerated read-only variables prefixed GPVAL_ and "show variables all"
  * NEW Japanese language documentation - FAQ and User Manual
  * NEW multi-platform and interactive wxWidgets terminal
  * NEW windows terminal supports enhanced text mode
  * NEW support for placement of individual rectangles within plot or canvas
  * NEW command "set style increment user" allows customization of default lines
  * NEW commands raise and lower
  * NEW y and y2 axis label rotation can be explicitly controlled (2D plots only)
  * NEW {no}enhanced flag can be applied to individual labels
  * NEW suboption 'set pm3d interpolate' for bilinear interpolation of surfaces
  * NEW 3D plots can read RGB color triples as part of input data
  * NEW write command history file also for gnuplot's readline
  * NEW more versatile key placement and arrangement
  * NEW 'splot x*y with pm3d' no longer requires prior 'set pm3d'
  * NEW store a sequence of plots to an animated gif (requires libgd > 2.0.28)
  * NEW multi-byte font support in x11, controlled by the locale setting LC_CTYPE
  * NEW control decimal sign conventions using locale setting LC_NUMERIC
  * NEW pstex, pslatex and epslatex terminals share functionality with postscript
  * NEW suboptions "set pm3d corners2color min|max"
  * NEW suboption  "set pm3d depthorder" does hidden-surface removal (sort of)
  * NEW linetype colors via "lt {palette {frac <val> | cb <val>}}"
  * NEW linetype colors via "lt {rgbcolor {"name" | "#RRGGBB"}}"
  * NEW palette and rgb linetype colors apply to all 2D and 3D plot elements
  * NEW user defined variables can contain strings
  * NEW expression evaluation can manipulate and return strings
  * NEW built-in string functions sprintf, gprintf, substr, strstrt, word, words
  * NEW built-in string function system("shell command")
  * NEW command line macro expansion   @<stringvariablename>
  * NEW automatic variable $# expanded to number of arguments after "call"
  * NEW reading of (almost) arbitrary image binary files
  * NEW plot styles "with image" and "with rgbimage"
  * NEW plot style "with labels" reads text data along with X/Y/Z coordinates
  * NEW plot style "with histograms" creates clustered or stacked histograms
  * NEW auto-layout of multiplot using "set multiplot layout <rows>, <cols>"
  * NEW variant of plot "with filledcurves" that fills the area between two curves
  * NEW variant of "with filledcurves" that fills only above or below the curve
  * NEW using options {x|y|z}ticlabels(<col>)
  * NEW option to read plot title from data file: set key autotitle columnheader
  * NEW command 'set termoption <foo>' changes single property of current terminal
  * NEW png driver supports antialiasing and TrueColor images
  * NEW encoding koi8-u
  * NEW plot style "with vectors" applies to both 2D and 3D plots
  * NEW plot style "with points" can read variable point size from input file
  * NEW "set tics" can change most settings for {x|y|z|cb}tics at once
  * NEW tic scale can be set per axis using "set {x|y|z|cb}tics scale"
  * CHANGE history file is written by default
  * CHANGE PostScript prolog and character encoding files now maintained separately
  * CHANGE Placement of z-axis label in 3D plots is now equivalent to x and y axes
  * CHANGE "set ticsscale" is deprecated, use "set tics scale" instead
  * CHANGE gnuplot on x11 has mousing always enabled on startup
  * CHANGE 'set datafile fortran' is now required in order to read D or Q constants
  * CHANGE let the string in '{s}plot ... notitle "string"' be silently ignored
  * CHANGE libgd versions 2.0.28+ support GIF images as well as PNG/JPEG
  * CHANGE remove old (non-libgd) GIF and PNG drivers
  * CHANGE X-resource gnuplot*ctrlq:on requires <ctrl>q to kill plot window
  * CHANGE X-resource gnuplot*exportselection:off disables plot->clipboard export
  * CHANGE prefer use of offset keyword in 'set [xyz]label "foo" offset -1,-1'
  * CHANGE 'set table "outfile"; ...; unset table' replaces 'set term table'
  * CHANGE 'defined(foo)' is deprecated; new syntax is 'exists("foo")'
  * FIXED empty datafiles are not a fatal error
  * FIXED setenv GNUTERM now works for png, jpeg, and gif drivers
  * FIXED PostScript output can be restricted to Level 1 compatible features
  * FIXED emf output is compatible with MSWin XP SP 2
  * FIXED limit size of X11 requests to half the maximum allowed by the X display
  * FIXED arrowheads drawn in solid lines even if the shaft is dotted (PostScript)
  * FIXED estimate true effective length of strings in enhanced text mode
  * FIXED clipping of filled curves
* Wed Aug 16 2006 sndirsch@suse.de
- gnuplot-4.0.0-fonts.dif: fixed font paths for X.Org 7
* Tue Jan 31 2006 werner@suse.de
- Fix stupid buffer overflow in x11 display program (bug #146870)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 21 2005 werner@suse.de
- Re-use libgd because we get jpeg/png support with truetype font
  and gif dummy support which is png output for term gif (#97208)
* Thu Feb 10 2005 ro@suse.de
- remove dropped tetex subpackages from nfb
* Thu Apr 29 2004 werner@suse.de
- Use GNU readline library
- Enable thin splines for 3D
* Tue Apr 27 2004 werner@suse.de
- Update to gnuplot 4.0.0
* Tue Apr 20 2004 meissner@suse.de
- aliasing fixes.
* Thu Oct 16 2003 meissner@suse.de
- Do not build as root.
- Fixed lib64 handling to be more correct, since 32bit systems
  can now have /lib64/ too.
* Fri Jun 13 2003 coolo@suse.de
- fixing docs installation
* Thu Jun 12 2003 coolo@suse.de
- use BuildRoot
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Mar 25 2003 werner@suse.de
- Make mouse patch work as it should
* Mon Mar 24 2003 werner@suse.de
- Update to gnuplot 3.7.3
- Port patches (if needed) to 3.7.3
* Fri Feb 28 2003 werner@suse.de
- Fix bug #23417: use intall-info for info file
* Fri Nov 22 2002 werner@suse.de
- Fix buffer overflow
- Fix svgalib handling for secure svgalibs
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Mon May  6 2002 werner@suse.de
- Do some lib64 stuff
* Thu Apr  4 2002 ro@suse.de
- more brackets for autoconf
* Sun Feb 10 2002 ro@suse.de
- tar option for bz2 is now "j"
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan  9 2002 ro@suse.de
- fixed to compile (don't include fcntl when building the help)
* Sat Jan  5 2002 kukuk@suse.de
- fix neededforbuild (plotutil -> plotutils)
* Tue Dec 18 2001 werner@suse.de
- Be sure that the waitforinput function is called even if real
  readline library is used or none interactive mode is on.  Be sure
  that the buffered token will be handles even if there is no
  activity on stdin and set a time out to be not blocked (#12625)
* Mon Nov 12 2001 ro@suse.de
- no svgalib
* Tue Jun 12 2001 schwab@suse.de
- Fix for new autoconf.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Thu Mar 29 2001 garloff@suse.de
- Prevent stupid rounding errors 10*10^23 instead of 10^24
  in graphics.c: mant_exp()
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Sun Dec  3 2000 schwab@suse.de
- Fix resource leak in X11 terminal driver.
* Wed Jun 21 2000 werner@suse.de
- Add French doc (somewhat out of date)
* Wed Jun  7 2000 werner@suse.de
- New version 3.7.1 with many bug fixes included
* Tue Jun  6 2000 uli@suse.de
- moved docs to /usr/share/doc
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Oct 11 1999 ro@suse.de
- disabled gdlib support (we have png anyway and gd doesn't support
  gif any more)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon May  3 1999 werner@suse.de
- Do not use system time because gnuplot interface isn't able
    to handle summer time
  - Use /tmp/ for temporaray files of demos
* Wed Mar 10 1999 werner@suse.de
- Fix from one of the authors (HBB) to avoid buffer overflow
* Tue Mar  9 1999 werner@suse.de
- New patchlevel 0.1 with patch gnuplot.990304 for security
* Tue Mar  2 1999 werner@suse.de
- New version: 3.7
  * add some official fixes
  * fix the official fix of fit.c
  * add gif and unixplot for output
* Sun Aug 23 1998 bs@suse.de
- fixed "neededforbuild"
* Mon Jul 13 1998 werner@suse.de
- New version: 3.5beta6.347
  * Security fix for svga linux driver call
  * Some enhancements
  * Some bug fixes
* Thu Oct 23 1997 werner@suse.de
- New version: 3.5beta6.336
* Mon Feb  3 1997 werner@suse.de
- Update auf Version 3.5-beta-3.6pl319
  - Diese Version hat splines und bezier zum Fit für
    von Messdaten.
  - verschoben von ap1 -> xap1
* Thu Jan  2 1997 werner@suse.de
- Neu Erstellen des Paketes:
    Mit vollständiger Dokumentation und Beispielen
    unter /usr/doc/packages/gnuplot/
  - fig und bfig (xfig-Format 2.1)
    wird von xfig in xfig-Format 3.2 konvertiert.
